// This file was generated by gir (https://github.com/gtk-rs/gir)
// from gir-files (https://github.com/gtk-rs/gir-files)
// DO NOT EDIT

#include "manual.h"
#include <stdalign.h>
#include <stdio.h>

int main() {
    printf("%s;%zu;%zu\n", "GdkAnchorHints", sizeof(GdkAnchorHints), alignof(GdkAnchorHints));
    printf("%s;%zu;%zu\n", "GdkAxisFlags", sizeof(GdkAxisFlags), alignof(GdkAxisFlags));
    printf("%s;%zu;%zu\n", "GdkAxisUse", sizeof(GdkAxisUse), alignof(GdkAxisUse));
    printf("%s;%zu;%zu\n", "GdkCicpRange", sizeof(GdkCicpRange), alignof(GdkCicpRange));
    printf("%s;%zu;%zu\n", "GdkContentProvider", sizeof(GdkContentProvider), alignof(GdkContentProvider));
    printf("%s;%zu;%zu\n", "GdkContentProviderClass", sizeof(GdkContentProviderClass), alignof(GdkContentProviderClass));
    printf("%s;%zu;%zu\n", "GdkCrossingMode", sizeof(GdkCrossingMode), alignof(GdkCrossingMode));
    printf("%s;%zu;%zu\n", "GdkDevicePadFeature", sizeof(GdkDevicePadFeature), alignof(GdkDevicePadFeature));
    printf("%s;%zu;%zu\n", "GdkDeviceToolType", sizeof(GdkDeviceToolType), alignof(GdkDeviceToolType));
    printf("%s;%zu;%zu\n", "GdkDmabufError", sizeof(GdkDmabufError), alignof(GdkDmabufError));
    printf("%s;%zu;%zu\n", "GdkDragAction", sizeof(GdkDragAction), alignof(GdkDragAction));
    printf("%s;%zu;%zu\n", "GdkDragCancelReason", sizeof(GdkDragCancelReason), alignof(GdkDragCancelReason));
    printf("%s;%zu;%zu\n", "GdkEventType", sizeof(GdkEventType), alignof(GdkEventType));
    printf("%s;%zu;%zu\n", "GdkFrameClockPhase", sizeof(GdkFrameClockPhase), alignof(GdkFrameClockPhase));
    printf("%s;%zu;%zu\n", "GdkFullscreenMode", sizeof(GdkFullscreenMode), alignof(GdkFullscreenMode));
    printf("%s;%zu;%zu\n", "GdkGLAPI", sizeof(GdkGLAPI), alignof(GdkGLAPI));
    printf("%s;%zu;%zu\n", "GdkGLError", sizeof(GdkGLError), alignof(GdkGLError));
    printf("%s;%zu;%zu\n", "GdkGravity", sizeof(GdkGravity), alignof(GdkGravity));
    printf("%s;%zu;%zu\n", "GdkInputSource", sizeof(GdkInputSource), alignof(GdkInputSource));
    printf("%s;%zu;%zu\n", "GdkKeyMatch", sizeof(GdkKeyMatch), alignof(GdkKeyMatch));
    printf("%s;%zu;%zu\n", "GdkKeymapKey", sizeof(GdkKeymapKey), alignof(GdkKeymapKey));
    printf("%s;%zu;%zu\n", "GdkMemoryFormat", sizeof(GdkMemoryFormat), alignof(GdkMemoryFormat));
    printf("%s;%zu;%zu\n", "GdkModifierType", sizeof(GdkModifierType), alignof(GdkModifierType));
    printf("%s;%zu;%zu\n", "GdkNotifyType", sizeof(GdkNotifyType), alignof(GdkNotifyType));
    printf("%s;%zu;%zu\n", "GdkPaintableFlags", sizeof(GdkPaintableFlags), alignof(GdkPaintableFlags));
    printf("%s;%zu;%zu\n", "GdkPaintableInterface", sizeof(GdkPaintableInterface), alignof(GdkPaintableInterface));
    printf("%s;%zu;%zu\n", "GdkRGBA", sizeof(GdkRGBA), alignof(GdkRGBA));
    printf("%s;%zu;%zu\n", "GdkRectangle", sizeof(GdkRectangle), alignof(GdkRectangle));
    printf("%s;%zu;%zu\n", "GdkScrollDirection", sizeof(GdkScrollDirection), alignof(GdkScrollDirection));
    printf("%s;%zu;%zu\n", "GdkScrollRelativeDirection", sizeof(GdkScrollRelativeDirection), alignof(GdkScrollRelativeDirection));
    printf("%s;%zu;%zu\n", "GdkScrollUnit", sizeof(GdkScrollUnit), alignof(GdkScrollUnit));
    printf("%s;%zu;%zu\n", "GdkSeat", sizeof(GdkSeat), alignof(GdkSeat));
    printf("%s;%zu;%zu\n", "GdkSeatCapabilities", sizeof(GdkSeatCapabilities), alignof(GdkSeatCapabilities));
    printf("%s;%zu;%zu\n", "GdkSubpixelLayout", sizeof(GdkSubpixelLayout), alignof(GdkSubpixelLayout));
    printf("%s;%zu;%zu\n", "GdkSurfaceEdge", sizeof(GdkSurfaceEdge), alignof(GdkSurfaceEdge));
    printf("%s;%zu;%zu\n", "GdkTextureError", sizeof(GdkTextureError), alignof(GdkTextureError));
    printf("%s;%zu;%zu\n", "GdkTimeCoord", sizeof(GdkTimeCoord), alignof(GdkTimeCoord));
    printf("%s;%zu;%zu\n", "GdkTitlebarGesture", sizeof(GdkTitlebarGesture), alignof(GdkTitlebarGesture));
    printf("%s;%zu;%zu\n", "GdkToplevelCapabilities", sizeof(GdkToplevelCapabilities), alignof(GdkToplevelCapabilities));
    printf("%s;%zu;%zu\n", "GdkToplevelState", sizeof(GdkToplevelState), alignof(GdkToplevelState));
    printf("%s;%zu;%zu\n", "GdkTouchpadGesturePhase", sizeof(GdkTouchpadGesturePhase), alignof(GdkTouchpadGesturePhase));
    printf("%s;%zu;%zu\n", "GdkVulkanError", sizeof(GdkVulkanError), alignof(GdkVulkanError));
    return 0;
}
